#!/usr/bin/env ruby
# $Id: certsec.rb,v 1.3 2016/05/13 10:32:59 stm Exp $
#
# PDFlib PLOP DS:
# Encrypt file with certificate security.
#

require './PLOP'

# create a new PLOP object
plop = PLOP.new

# This is where input files live. Adjust as necessary.
searchpath = "../data"

recipients = [
  # no permission restrictions
  { "cert" => "../data/demo_recipient_1.pem", "perm" => "" },

  # form filling and signing permissions granted, but not others
  { "cert" => "../data/demo_recipient_2.pem", "perm" => "nomodify nocopy noannots noassemble" },
  { "cert" => "../data/demo_recipient_3.pem", "perm" => "nomodify nocopy noannots noassemble" },
]

begin
    if (ARGV.length != 2 )
	raise "usage: certsec <infile> <outfile>\n"
    end

    plop.set_option("searchpath={#{searchpath}}")

    # open unprotected input file
    if ((doc = plop.open_document(ARGV[0], "")) == -1)
	raise "ERROR: " + plop.get_errmsg()
    end

    # add recipients
    recipients.each do |r|
        optlist = "certificate={filename={#{r["cert"]}}} permissions={#{r["perm"]}}"
        if (plop.add_recipient(optlist) == -1)
            # emit warning and continue
            print("Error: " + plop.get_errmsg() + "\n")
        end
    end

    # create protected output file
    if (plop.create_document(ARGV[1], "input=#{doc}") == -1)
        raise "ERROR: " + plop.get_errmsg()
    end
	
    plop.close_document(doc, "")

rescue PLOPException => pe
    print pe.backtrace.join("\n")
    printf("PLOP exception occurred in certsec\n")
    print "[" + pe.get_errnum.to_s + "] " + pe.get_apiname + \
                        ": " + pe.get_errmsg + "\n"
rescue Exception => e
    print e.backtrace.join("\n") + "\n" + e.to_s + "\n"
ensure
    plop.delete() if plop
end
